/*
 * netconfig.c - netconfig main routines
 * by Jonathan Kay, Computer Systems Lab, UCSD         8/3/93
 *
 * Copyright (c) 1993,1994 Regents of the University of California.
 * All rights reserved.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose, without fee, and without written agreement is
 * hereby granted, provided that the above copyright notice and the following
 * paragraph appears in all copies of this software.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
 * EVENT SHALL THE REGENTS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <stdio.h>
#include <sys/types.h>
#include "error.h"
#include "vars.h"
#include "configurable.h"

extern Configurable Cfgbls[];
extern struct var *kreadq, *kwriteq;
extern int nkread, nkwrite;

int doprint = 0;    /* Look and see if there's anything fit to print */
int existwarn = 1;  /* Should warning be printed if a var doesn't exist?
		       Default is yes except in case of multiple vars. */

char *cmdname;
char *kname = 0L;

main(argc, argv)
int argc;
char **argv;
{
    char *arg;
    int i;
    Var *v, *maybev;

    cmdname = argv[0];
    while (--argc) {
	arg = *++argv;
	if (arg[0] == '-') {
	    while (*++arg) {
		switch(*arg) {
		  case 'k':	/* kernel name */
		    --argc;
		    if (argc < 1)
			usage();
		    kname = *++argv;
		    break;
		  default:
		    usage();
		}
	    }
	}
	else if ((v = find_var(arg)) == 0) {
	    usage();
	}
	else {
	  gotv:
	    if (--argc <= 0) {
		access_readq(v);
		break;
	    }
	    arg = *++argv;
	    if (maybev = find_var(arg)) {
		access_readq(v);
		v = maybev;
		goto gotv;
	    }
	    access_writeq(v, arg);
	}
    }

    if (!kreadq && !kwriteq)
	getall();

    access_init();
    access_exec();
    if (doprint)
	print_all();
    exit(0);
}

getall()
{
    Configurable *cf;
    Var *v;
    
    for (cf = Cfgbls; cf->name[0]; ++cf) {
	for (v = cf->variables; v->xname[0]; ++v)
	    access_readq(v);
    }
}

usage()
{
    fprintf(stderr, "usage: %s [-k <kernel>] [<network-variable> [value]]...\n",
	    cmdname);
    exit(1);
}
