/*
 * print.c - pretty printing for netconfig
 * by Jonathan Kay, Computer Systems Lab, UCSD         8/3/93
 *
 * Copyright (c) 1993,1994 Regents of the University of California.
 * All rights reserved.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose, without fee, and without written agreement is
 * hereby granted, provided that the above copyright notice and the following
 * paragraph appears in all copies of this software.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
 * EVENT SHALL THE REGENTS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <stdio.h>
#include "vars.h"
#include "configurable.h"

#define VALUECOL  40

static doprintcf();

extern Configurable Cfgbls[];

print_all()
{
    Configurable *cf;
    Var *v;
    
    for (cf = Cfgbls; cf->name[0]; ++cf) {
	if (doprintcf(cf)) {
	    printf("%s:\n", cf->name);
	    for (v = cf->variables; v->xname[0]; ++v)
		print_var(v);
	}
    }
}

print_var(v)
Var *v;
{
    int nspaces;
    
    if (v->foundname && v->value && (v->accflags & VAF_READ)) {
	printf("    %s (%s):", v->xname, v->foundname);
	nspaces = VALUECOL - strlen(v->xname) - strlen(v->foundname);
	while (nspaces-- > 0)
	    putchar(' ');
	switch(v->type) {
	  case VT_INT:
	    printf("%d", *(int *)v->value);
	    break;
	  case VT_BOOL:
	    printf("%s", *(int *)v->value ? "on" : "off");
	    break;
	  default:
	    printf("%d (WARNING: UNKNOWN TYPE)\n", *(int *) v->value);
	    break;
	}
	putchar('\n');
    }
}

/*
 * Should I print a given configurable?  Policy is to print
 * it iff at least one of its variables was read.
 */
static doprintcf(cf)
	Configurable *cf;
{
    Var *v;
    
    for (v = cf->variables; v->xname[0]; ++v) {
	if (v->value && (v->accflags & VAF_READ))
	    return(1);
    }
    return(0);
}
