/*
 * tables.c - tables of protocols and variables
 * by Jonathan Kay, Computer Systems Lab, UCSD         8/3/93
 *
 * Copyright (c) 1993,1994 Regents of the University of California.
 * All rights reserved.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose, without fee, and without written agreement is
 * hereby granted, provided that the above copyright notice and the following
 * paragraph appears in all copies of this software.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
 * EVENT SHALL THE REGENTS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "vars.h"
#include "configurable.h"

Var SocketVariables[] = {
{ "Max socket buffer size", sizeof(int), VT_INT,
      { "_sb_max", "sb_max", "_sbmax", "sbmax", 0 } },
{ "Large mbuf use threshold", sizeof(int), VT_INT,
      { "_mbuf_threshold", "mbuf_threshold", "_mbufthreshold", "mbufthreshold", 0 } },
{ "Max listen queue len", sizeof(int), VT_INT,
      { "_so_maxconn", "so_maxconn", "_somaxconn", "somaxconn", 0 } },
{ "" }
};


Var InetVariables[] = {
{ "Internet checksum routine active", sizeof(int), VT_BOOL,
      { "_no_cksum", "no_cksum", "_nocksum", "nocksum", 0 } },
{ "" }
};


Var IPVariables[] = {
{ "Routing", sizeof(int), VT_INT,
      { "_ip_forwarding", "ip_forwarding", "_ipforwarding", "ipforwarding", 0 } },

{ "Checksum",		sizeof(int), VT_BOOL,
	 { "_ip_cksum", "ip_cksum", "_ipcksum", "ipcksum", 0 } },

{ "Ipgateway" ,         sizeof(int), VT_BOOL,
	 { "_ip_gateway", "ip_gateway", "_ipgateway", "ipgateway", 0 } },

{ "Verbose", sizeof(int), VT_BOOL,
      { "_ip_printfs", "ip_printfs", "_ipprintfs", "ipprintfs", 0 } },

{ "" }
};


Var ICMPVariables[] = {
{ "Redirects", sizeof(int), VT_BOOL,
	 { "_ip_sendredirects", "ip_sendredirects", "_ipsendredirects",
		   "ipsendredirects", 0 } },

{ "ICMP Message TTL", sizeof(int), VT_INT, { "maxttl", 0 } },

{ "Verbose", 	sizeof(int), VT_BOOL,
	 { "_icmp_printfs", "icmp_printfs", "_icmpprintfs",
		   "icmpprintfs", 0 } },

{ "" }
};


Var TCPVariables[] = {
{ "Output Buffer Size", sizeof(int), VT_INT,
	  { "_tcp_sendspace", "tcp_sendspace", "_tcpsendspace",
		    "tcpsendspace", 0 } },

{ "Input Buffer Size",	sizeof(int), VT_INT,
	  { "_tcp_recvspace", "tcp_recvspace", "_tcprecvspace",
		    "tcprecvspace", 0 } },

{"Retransmit Threshold",	sizeof(int), VT_INT,
	{ "_tcp_rexmtthresh", "tcp_rexmtthresh", "_tcprexmtthresh",
		  "tcprexmtthresh", 0 } },

{ "No Delayed ACK",	sizeof(int), VT_BOOL,
	 { "_tcp_nodelack", "tcp_nodelack", "_tcpnodelack", "tcpnodelack", 0 } },

{"Default Max Seg Size", sizeof(int), VT_INT,
	 { "_tcp_mssdflt", "tcp_mssdflt", "_tcpmssdflt", "tcpmssdflt",
		   "_tcp_default_mss", "tcp_default_mss", 0 } },

{ "Keepalive Length", sizeof(int), VT_INT,
	 { "_tcp_keeplen", "tcp_keeplen", "_tcpkeeplen", "tcpkeeplen" , 0 } },

{ "Keepalive Idle Time", sizeof(int), VT_INT,
	 { "_tcp_keepidle", "tcp_keepidle", "_tcpkeepidle", "tcpkeepidle", 0 } },

{ "Keepalive Interval",	sizeof(int), VT_INT,
	 { "_tcp_keepintvl", "tcp_keepintvl", "_tcpkeepintvl",
		   "tcpkeepintvl", 0 } },

{ "Default TTL", sizeof(int), VT_INT,
	 { "_tcp_ttl", "tcp_ttl", "_tcpttl", "tcpttl", 0 } },

{ "Don't scale windows",	sizeof(int), VT_BOOL,
	 { "_tcp_dont_winscale", "tcp_dont_winscale", 0 } },

{ "Receive Checksum", sizeof(int), VT_BOOL,
	 { "_tcp_cksum", "tcp_cksum", "_tcpcksum", "tcpcksum", 0 } },

{ "Verbose", sizeof(int), VT_BOOL,
	 { "_tcp_printfs", "tcp_printfs", "_tcpprintfs", "tcpprintfs", 0 } },

{ "Local Checksum",		sizeof(int), VT_BOOL,
	 { "_tcplclsum", "tcplclsum", 0 } },

{ "Subnets Are Local",	sizeof(int), VT_BOOL,
      { "_ip_subnetslocal", "ip_subnetslocal", "_ipsubnetslocal",
	    "ipsubnetslocal", "_subnetsarelocal", "subnetsarelocal", 0 } },

{ "All Nets Are Local",	sizeof(int), VT_BOOL,
      { "_ip_allnetslocal", "ip_allnetslocal", "_ipallnetslocal",
	    "ipallnetslocal", "_allnetsarelocal", "allnetsarelocal", 0 } },

{ "" }
};

Var UDPVariables[] = {
{ "Checksum",		sizeof(int), VT_BOOL,
	 { "_udp_cksum", "udp_cksum", "_udpcksum", "udpcksum", 0 } },

{ "Max Send Msg Size",	sizeof(int), VT_INT,
	 { "_udp_sendspace", "udp_sendspace", "_udpsendspace",
		   "udpsendspace", 0 } },

{ "Max Rcv Buffer",	sizeof(int), VT_INT,
	 { "_udp_recvspace", "udp_recvspace", "_udprecvspace",
		   "udprecvspace", 0 } },

{ "Default TTL", sizeof(int), VT_INT,
	 { "_udp_ttl", "udp_ttl", "_udpttl", "udpttl", 0 } },

{ "Local Checksum",		sizeof(int), VT_BOOL,
	 { "_udp_lclsum", "udp_lclsum", "_udplclsum", "udplclsum", 0 } },

{ "" }
};

Configurable Cfgbls[] = {
    { "Sockets", SocketVariables },
    { "IP",      IPVariables },
    { "ICMP",    ICMPVariables },
    { "TCP",     TCPVariables },
    { "UDP",     UDPVariables },
    { "TCP/IP Misc.", InetVariables },
    { "" }
};

